summaryrefslogtreecommitdiffstats
path: root/quanta/project/projectprivate.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/project/projectprivate.cpp')
-rw-r--r--quanta/project/projectprivate.cpp46
1 files changed, 23 insertions, 23 deletions
diff --git a/quanta/project/projectprivate.cpp b/quanta/project/projectprivate.cpp
index 871ae7bc..e5a9e8e5 100644
--- a/quanta/project/projectprivate.cpp
+++ b/quanta/project/projectprivate.cpp
@@ -254,11 +254,11 @@ void ProjectPrivate::openCurrentView()
TQDomElement el2 = itemNodes.item(j).cloneNode().toElement();
KURL url = baseURL;
QuantaCommon::setUrl(url,el2.attribute("url"));
- url = TQExtFileInfo::toAbsolute(url, baseURL);
+ url = QExtFileInfo::toAbsolute(url, baseURL);
if (el2.nodeName() == "viewitem")
{
urlsInView.append(url);
- if (!ViewManager::ref()->isOpened(url) && TQExtFileInfo::exists(url, true, m_mainWindow))
+ if (!ViewManager::ref()->isOpened(url) && QExtFileInfo::exists(url, true, m_mainWindow))
urlsToOpen.append(url);
} else {
if (el2.nodeName() == "viewtoolbar")
@@ -325,7 +325,7 @@ void ProjectPrivate::insertFiles( KURL::List files )
if (!m_projectFiles.tqcontains(url))
{
el = dom.createElement("item");
- el.setAttribute("url", QuantaCommon::qUrl(TQExtFileInfo::toRelative(url, baseURL, false)));
+ el.setAttribute("url", QuantaCommon::qUrl(QExtFileInfo::toRelative(url, baseURL, false)));
dom.firstChild().firstChild().appendChild(el);
m_projectFiles.insert( new ProjectURL(url, "", 1, false, el) );
emit eventHappened("after_project_add", url.url(), TQString());
@@ -337,7 +337,7 @@ void ProjectPrivate::insertFiles( KURL::List files )
url = *it;
if (!excludeRx.exactMatch(url.path()))
{
- el.setAttribute("url", QuantaCommon::qUrl(TQExtFileInfo::toRelative(url, baseURL, false)));
+ el.setAttribute("url", QuantaCommon::qUrl(QExtFileInfo::toRelative(url, baseURL, false)));
dom.firstChild().firstChild().appendChild(el);
m_projectFiles.insert( new ProjectURL(url, "", 1, false, el) );
emit eventHappened("after_project_add", url.url(), TQString());
@@ -362,7 +362,7 @@ void ProjectPrivate::insertFiles(const KURL& pathURL, const TQString& tqmask )
KURL::List list;
list.append(pathURL);
- list += TQExtFileInfo::allFiles(pathURL, tqmask, m_mainWindow);
+ list += QExtFileInfo::allFiles(pathURL, tqmask, m_mainWindow);
insertFiles(list);
}
@@ -464,7 +464,7 @@ void ProjectPrivate::loadProjectXML()
if (tmpString != QuantaCommon::qUrl(templateURL) )
{
el = no.toElement();
- url = TQExtFileInfo::toRelative(templateURL, baseURL);
+ url = QExtFileInfo::toRelative(templateURL, baseURL);
if(el.isNull())
{
el = dom.createElement("templates");
@@ -476,7 +476,7 @@ void ProjectPrivate::loadProjectXML()
el.firstChild().setNodeValue(QuantaCommon::qUrl(url));
}
}
- templateURL = TQExtFileInfo::toAbsolute(templateURL, baseURL);
+ templateURL = QExtFileInfo::toAbsolute(templateURL, baseURL);
no = projectNode.namedItem("toolbars");
toolbarURL = baseURL;
@@ -492,7 +492,7 @@ void ProjectPrivate::loadProjectXML()
if (tmpString != QuantaCommon::qUrl(toolbarURL))
{
el = no.toElement();
- url = TQExtFileInfo::toRelative(toolbarURL, baseURL);
+ url = QExtFileInfo::toRelative(toolbarURL, baseURL);
if(el.isNull())
{
el = dom.createElement("toolbars");
@@ -504,7 +504,7 @@ void ProjectPrivate::loadProjectXML()
el.firstChild().setNodeValue(QuantaCommon::qUrl(url));
}
}
- toolbarURL = TQExtFileInfo::toAbsolute(toolbarURL, baseURL);
+ toolbarURL = QExtFileInfo::toAbsolute(toolbarURL, baseURL);
no = projectNode.namedItem("exclude");
m_excludeCvsignore = (no.toElement().attribute("cvsignore", "false") == "true");
@@ -739,7 +739,7 @@ void ProjectPrivate::slotAcceptCreateProject()
if (baseURL.protocol() == i18n("Local")) baseURL.setProtocol("file");
baseURL.adjustPath(1);
if (!baseURL.path().startsWith("/")) baseURL.setPath("/"+ baseURL.path());
- if (!TQExtFileInfo::createDir(baseURL, m_mainWindow))
+ if (!QExtFileInfo::createDir(baseURL, m_mainWindow))
{
QuantaCommon::dirCreationError(m_mainWindow, baseURL);
baseURL = oldBaseURL;
@@ -789,7 +789,7 @@ void ProjectPrivate::slotAcceptCreateProject()
for ( KURL::List::Iterator it = list.begin(); it != list.end(); ++it )
{
- url = *it;//TQExtFileInfo::toRelative(*it, baseURL );
+ url = *it;//QExtFileInfo::toRelative(*it, baseURL );
el = dom.createElement("item");
el.setAttribute("url",QuantaCommon::qUrl(url));
dom.firstChild().firstChild().appendChild( el );
@@ -823,28 +823,28 @@ void ProjectPrivate::slotAcceptCreateProject()
{
QuantaCommon::setUrl(templateURL, png->linePrjTmpl->text());
templateURL.adjustPath(1);
- templateURL = TQExtFileInfo::toAbsolute(templateURL, baseURL);
- if (!TQExtFileInfo::createDir(templateURL, m_mainWindow))
+ templateURL = QExtFileInfo::toAbsolute(templateURL, baseURL);
+ if (!QExtFileInfo::createDir(templateURL, m_mainWindow))
{
QuantaCommon::dirCreationError(m_mainWindow, templateURL);
}
}
//the nodes are already created in loadProjectXML() called from createEmptyDom()
el = dom.firstChild().firstChild().namedItem("templates").toElement();
- url = TQExtFileInfo::toRelative(templateURL, baseURL);
+ url = QExtFileInfo::toRelative(templateURL, baseURL);
el.firstChild().setNodeValue(QuantaCommon::qUrl(url));
//setup the toolbars directory
toolbarURL = baseURL;
QuantaCommon::setUrl(toolbarURL,png->linePrjToolbar->text());
toolbarURL.adjustPath(1);
- toolbarURL = TQExtFileInfo::toAbsolute(toolbarURL, baseURL);
- if (!TQExtFileInfo::createDir(toolbarURL, m_mainWindow))
+ toolbarURL = QExtFileInfo::toAbsolute(toolbarURL, baseURL);
+ if (!QExtFileInfo::createDir(toolbarURL, m_mainWindow))
{
QuantaCommon::dirCreationError(m_mainWindow, toolbarURL);
}
el = dom.firstChild().firstChild().namedItem("toolbars").toElement();
- url = TQExtFileInfo::toRelative(toolbarURL, baseURL);
+ url = QExtFileInfo::toRelative(toolbarURL, baseURL);
el.firstChild().setNodeValue(QuantaCommon::qUrl(url));
#if KDE_IS_VERSION(3,4,89)
@@ -939,7 +939,7 @@ void ProjectPrivate::slotSaveAsProjectView(bool askForName)
if (m_projectFiles.tqcontains(url))
{
item = dom.createElement("viewitem");
- item.setAttribute("url", QuantaCommon::qUrl(TQExtFileInfo::toRelative(url, baseURL)) );
+ item.setAttribute("url", QuantaCommon::qUrl(QExtFileInfo::toRelative(url, baseURL)) );
el.appendChild(item);
}
}
@@ -950,7 +950,7 @@ void ProjectPrivate::slotSaveAsProjectView(bool askForName)
{
item = dom.createElement("viewtoolbar");
KURL url = toolbarList[i];
- url = TQExtFileInfo::toRelative(url, baseURL);
+ url = QExtFileInfo::toRelative(url, baseURL);
item.setAttribute("url", QuantaCommon::qUrl(url) );
el.appendChild(item);
}
@@ -1008,7 +1008,7 @@ bool ProjectPrivate::createEmptyDom()
tempFile->textStream()->setEncoding(TQTextStream::UnicodeUTF8);
*(tempFile->textStream()) << str;
tempFile->close();
- result = TQExtFileInfo::createDir(baseURL, m_mainWindow);
+ result = QExtFileInfo::createDir(baseURL, m_mainWindow);
if (result)
result = KIO::NetAccess::upload(tempFile->name(), projectURL, m_mainWindow);
if (result)
@@ -1100,7 +1100,7 @@ void ProjectPrivate::getStatusFromTree()
}
TQStringList folderList;
tqparent->getTreetqStatus( &folderList );
// toplevel folder is always open in a project and TQExtFileInfo::toRelative
// creates strange output -> we remove the toplevel folder
if (folderList.count() > 0)
folderList.remove(folderList.begin());
@@ -1110,7 +1110,7 @@ void ProjectPrivate::getStatusFromTree()
m_sessionDom.firstChild().firstChild().appendChild(root);
for (TQStringList::Iterator it = folderList.begin(); it != folderList.end(); ++it) {
el = m_sessionDom.createElement("openfolder");
- el.setAttribute("url", QuantaCommon::qUrl( TQExtFileInfo::toRelative(KURL(*it), baseURL) ) );
+ el.setAttribute("url", QuantaCommon::qUrl( QExtFileInfo::toRelative(KURL(*it), baseURL) ) );
root.appendChild( el );
}
}
@@ -1432,7 +1432,7 @@ void ProjectPrivate::slotAddFiles()
if ( !list.isEmpty() )
{
KURL firstURL = list.first();
- firstURL = TQExtFileInfo::toRelative( firstURL, baseURL );
+ firstURL = QExtFileInfo::toRelative( firstURL, baseURL );
if ( firstURL.path().startsWith("/") || firstURL.path().startsWith("."))
{
@@ -1100,7 +1100,7 @@ void ProjectPrivate::getStatusFromTree()
TQStringList folderList;
tqparent->getTreetqStatus( &folderList );
- // toplevel folder is always open in a project and TQExtFileInfo::toRelative
+ // toplevel folder is always open in a project and QExtFileInfo::toRelative
// creates strange output -> we remove the toplevel folder
if (folderList.count() > 0)